from setuptools import setup, find_packages

setup(
    name="mymol",  # Your package name
    version="1.0.0",  # Package version
    author="Arthur Kwak",
    author_email="tureluurtje.1@gmail.com",
    description="Useful things",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    license="MIT",  # License type
    packages=find_packages(),  # Automatically find and include all packages
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",  # Minimum Python version requirement
    install_requires=['anyio==4.8.0',
 'certifi==2024.12.14',
 'charset-normalizer==3.4.1',
 'click==8.1.8',
 'colorama==0.4.6',
 'contourpy==1.3.1',
 'cursor==1.3.5',
 'cycler==0.12.1',
 'fonttools==4.55.4',
 'future==1.0.0',
 'gitdb==4.0.12',
 'GitPython==3.1.44',
 'halo==0.0.28',
 'idna==3.10',
 'inexactsearch==1.0.2',
 'ipaddress==1.0.23',
 'Jinja2==3.1.5',
 'joblib==1.4.2',
 'kiwisolver==1.4.8',
 'log-symbols==0.0.14',
 'MarkupSafe==3.0.2',
 'matplotlib==3.10.0',
 'mysql-connector==2.2.9',
 'nltk==3.9.1',
 'numpy==2.2.2',
 'packaging==24.2',
 'pillow==11.1.0',
 'pip-chill==1.0.3',
 'pyaml==25.1.0',
 'pycryptodomex==3.21.0',
 'pyparsing==3.2.1',
 'pyperclip==1.9.0',
 'pyspellchecker==0.8.2',
 'python-dateutil==2.9.0.post0',
 'pywin32==308',
 'PyYAML==6.0.2',
 'regex==2024.11.6',
 'requests==2.32.3',
 'scikit-learn==1.6.1',
 'scipy==1.15.1',
 'sentry-sdk==2.20.0',
 'setuptools==75.8.0',
 'silpa_common==0.3',
 'six==1.17.0',
 'smmap==5.0.2',
 'sniffio==1.3.1',
 'soundex==1.1.3',
 'spell==0.48.9',
 'spellchecker==0.4',
 'spinners==0.0.24',
 'starlette==0.45.2',
 'tabulate==0.9.0',
 'termcolor==2.5.0',
 'threadpoolctl==3.5.0',
 'tqdm==4.67.1',
 'urllib3==2.3.0',
 'wordcloud==1.9.4'],  # List dependencies here
)
